@@ -88,6 +88,8 @@ class Forum(object):
                 t_off += 20
                 tpage -= 1
             tpage = page
+            if tpage == 1:
+                result['first'] == None
             max_page = tpage + 2
             t_off = 0
             while tpage <= max_page and result['last'][0] != tpage:
